{% extends "../core/setup.html" %}
{% load i18n %}
{% load static %}
{% load render_kakebo %}

{% block style %}
<link href="{% static 'basic/assets/css/c_style.css' %}" rel="stylesheet">
<link href="{% static 'basic/assets/css/kakebo-style.css' %}" rel="stylesheet">
{% endblock style %}

{% block content %}
<section class="section-padding">
	<div class="container-fluid">
		<div class="row">
			<div class="col-11 m-auto">
				<form method="POST">{% csrf_token %}

					<table class="w-100">
						<thead>
						<tr>
							<th class="text-center" width="7%"></th>
							{% for val in cell_ %}
							<th class="text-center" width="11.6%">
								{{ val }}
							</th>
							{% endfor %}
							<th class="text-center" width="12.4%" colspan="2">
								{% trans 'Week releases' %}
							</th>
						</tr>
						</thead>

						{% for value in list_tr %}
						{% render_table value.0 value.1 value.2 key_kakebo disabled %}
						{% white_space_table %}
						{% endfor %}

						{% render_table_total totals_days total_week %}

					</table>

				</form>
			</div>
		</div>
	</div>
</section>
{% endblock content %}