<!DOCTYPE html>
<html lang="en">
<head>

	<title>
		{% block title %}
		User Title
		{% endblock title %}
	</title>
	{% include './partials/head_style.html' %}

</head>
<body>

{% block content %}
{% endblock content %}

</body>
</html>