<footer class="site-footer section-padding">
	<div class="container">
		<div class="row">

			<div class="col-lg-3 col-12 mb-4 pb-2">
				<a class="navbar-brand mb-2" href="{% url 'kakebo-home' %}">
					<i class="bi bi-piggy-bank"></i>
					<span>
						Kakebo
					</span>
				</a>
			</div>

			<div class="col-lg-3 col-md-4 col-6">
				<h6 class="site-footer-title mb-3">
					Sections

				</h6>

				<ul class="site-footer-links">
					<li class="site-footer-link-item">
						<a href="#" class="site-footer-link">
							Home
						</a>
					</li>

					<li class="site-footer-link-item">
						<a class="site-footer-link" href="#section_1">
							Scopri il Kakebo
						</a>
					</li>

					<li class="site-footer-link-item">
						<a class="site-footer-link" href="#section_2">
							5 motivi per usarlo
						</a>
					</li>

					<li class="site-footer-link-item">
						<a class="site-footer-link" href="#section_3">
							FAQs
						</a>
					</li>

					<li class="site-footer-link-item">
						<a class="site-footer-link" href="#section_4">
							Contact
						</a>
					</li>
				</ul>
			</div>

			<div class="col-lg-3 col-md-4 col-6 mb-4 mb-lg-0">
				<h6 class="site-footer-title mb-3">
					Contacts
				</h6>

				<p class="text-white d-flex mb-1">
					<a class="site-footer-link" href="tel:+390000000000">
						+39 000 0000 000
					</a>
				</p>

				<p class="text-white d-flex">
					<a class="site-footer-link" href="mailto:support@shadmod.it">
						support@shadmod.it
					</a>
				</p>
			</div>

			<div class="col-lg-3 col-md-4 col-12 mt-4 mt-lg-0 ms-auto">
				<div class="dropdown">
					<button class="btn btn-secondary dropdown-toggle" type="button" data-bs-toggle="dropdown"
							aria-expanded="false">
						English
					</button>

					<ul class="dropdown-menu">
						<li>
							<button class="dropdown-item" type="button">
								Italian
							</button>
						</li>
					</ul>
				</div>

				<p class="copyright-text mt-lg-5 mt-4">
					All right reserved - © ShadMod 2023
				</p>
			</div>

		</div>
	</div>
</footer>