{% load static %}
<script src="{% static 'basic/assets/js/jquery.min.js' %}"></script>
<script src="{% static 'vendor/bootstrap/js/bootstrap.bundle.min.js' %}"></script>
<script src="{% static 'basic/assets/js/jquery.sticky.js' %}"></script>
<script src="{% static 'basic/assets/js/custom.js' %}"></script>